@@ -271,13 +271,6 @@ Playback::~Playback()
   // Do nothing
 }
 
-//////////////////////////////////////////////////
-PlaybackHandlePtr Playback::Start(
-    const std::chrono::nanoseconds &_waitAfterAdvertising) const
-{
-  return this->Start(_waitAfterAdvertising, true);
-}
-
 //////////////////////////////////////////////////
 PlaybackHandlePtr Playback::Start(
     const std::chrono::nanoseconds &_waitAfterAdvertising,
